API reference
=============

``appsettings``
---------------

.. automodule:: appsettings

.. autoclass:: appsettings.AppSettings
    :members:

.. autoclass:: appsettings.Setting
    :members:

    .. automethod:: __init__
